<?php
 /**
 * Contact Widget
 */
class Cyarb_contact_info extends WP_Widget{

    function __construct(){
        $widget_ops = array('description' => esc_html__('Display Contact Info', 'cyarb-toolkit'));
        parent::__construct( false, esc_html__('Cyarb Footer Contact', 'cyarb-toolkit'), $widget_ops);
    }

    function widget($args, $instance){
        extract($args);
        global $cyarb_theme;

        $title  = apply_filters('widget_title', $instance['title']);

        echo wp_kses_post($before_widget);
        ?>
            <h3><?php echo esc_html($instance['title']); ?></h3>
            <ul class="footer-contact-info">
                <?php if( $instance['address'] != '' ): ?>
                    <li>
                        <span><?php echo esc_html($instance['address_label']); ?></span>
                        <?php echo esc_html($instance['address']); ?>
                    </li>
                <?php endif; ?>

                <?php if( $instance['email'] != '' ): ?>
                    <li>
                        <span><?php echo esc_html($instance['email_label']); ?></span>
                        <a href="<?php echo esc_url($instance['email_url']); ?>"><?php echo esc_html($instance['email']); ?></a>
                    </li>
                <?php endif; ?>

                <?php if( $instance['phone'] != '' ): ?>
                    <li>
                        <span><?php echo esc_html($instance['phone_label']); ?></span>
                        <a href="<?php echo esc_url($instance['phone_url']); ?>"><?php echo esc_html($instance['phone']); ?></a>
                    </li>
                <?php endif; ?>

                <?php if( $instance['fax'] != '' ): ?>
                    <li>
                        <span><?php echo esc_html($instance['fax_label']); ?></span>
                        <a href="<?php echo esc_url($instance['fax_url']); ?>"><?php echo esc_html($instance['fax']); ?></a>
                    </li>
                <?php endif; ?>
            </ul>

        <?php
        echo wp_kses_post($after_widget);
    }

    function update($new_instance, $old_instance){
        $instance                           = $old_instance;
        $instance['title']                  = strip_tags($new_instance['title']);
        $instance['address_label']          = $new_instance['address_label'];
        $instance['address']                = $new_instance['address'];
        $instance['email_label']            = $new_instance['email_label'];
        $instance['email_url']              = $new_instance['email_url'];
        $instance['email']                  = $new_instance['email'];
        $instance['phone_label']            = $new_instance['phone_label'];
        $instance['phone_url']              = $new_instance['phone_url'];
        $instance['phone']                  = $new_instance['phone'];
        $instance['fax_label']              = $new_instance['fax_label'];
        $instance['fax_url']                = $new_instance['fax_url'];
        $instance['fax']                    = $new_instance['fax'];

        return $instance;
    }

    function form($instance){
        $defaults = array(
            'title'                     => esc_html__('Contact Us', 'cyarb-toolkit'),
            'address_label'             => 'Address:',
            'address'                   => '2750 Quadra Street Victoria, Canada.',
            'email_label'               => 'Email:',
            'email_url'                 => 'mailto:hello@cyarb.com',
            'email'                     => 'hello@cyarb.com',
            'phone_label'               => 'Phone:',
            'phone_url'                 => 'tel:+1-485-456-0102',
            'phone'                     => '+1-485-456-0102',
            'fax_label'                 => 'Fax:',
            'fax_url'                   => 'tel:+1-07854578964',
            'fax'                       => '+1-0785 4578964',
        );
        $instance = wp_parse_args((array)$instance, $defaults);
        ?>

        <p>
            <label for="<?php echo esc_attr($this->get_field_id('title')); ?>">
                <?php esc_html_e('Title:', 'cyarb-toolkit'); ?>
                <input class="widget" id="<?php echo esc_attr($this->get_field_id('title')); ?>" name="<?php echo esc_attr($this->get_field_name('title')); ?>" type="text" value="<?php echo wp_kses_post($instance['title']); ?>" />
            </label>
        </p>

        <p>
            <label for="<?php echo esc_attr($this->get_field_id('address_label')); ?>">
                <?php esc_html_e('Address Label:', 'cyarb-toolkit'); ?>
                <input class="widget" id="<?php echo esc_attr($this->get_field_id('address_label')); ?>" name="<?php echo esc_attr($this->get_field_name('address_label')); ?>" type="text" value="<?php echo wp_kses_post($instance['address_label']); ?>" />
            </label>
        </p>

        <p>
            <label for="<?php echo esc_attr($this->get_field_id('address')); ?>">
                <?php esc_html_e('Address:', 'cyarb-toolkit'); ?>
                <input class="widget" id="<?php echo esc_attr($this->get_field_id('address')); ?>" name="<?php echo esc_attr($this->get_field_name('address')); ?>" type="text" value="<?php echo wp_kses_post($instance['address']); ?>" />
            </label>
        </p>

        <p>
            <label for="<?php echo esc_attr($this->get_field_id('email_label')); ?>">
                <?php esc_html_e('Email Label:', 'cyarb-toolkit'); ?>
                <input class="widget" id="<?php echo esc_attr($this->get_field_id('email_label')); ?>" name="<?php echo esc_attr($this->get_field_name('email_label')); ?>" type="text" value="<?php echo wp_kses_post($instance['email_label']); ?>" />
            </label>
        </p>

        <p>
            <label for="<?php echo esc_attr($this->get_field_id('email_url')); ?>">
                <?php esc_html_e('Email URL:', 'cyarb-toolkit'); ?>
                <input class="widget" id="<?php echo esc_attr($this->get_field_id('email_url')); ?>" name="<?php echo esc_attr($this->get_field_name('email_url')); ?>" type="text" value="<?php echo wp_kses_post($instance['email_url']); ?>" />
            </label>
        </p>

        <p>
            <label for="<?php echo esc_attr($this->get_field_id('email')); ?>">
                <?php esc_html_e('Email:', 'cyarb-toolkit'); ?>
                <input class="widget" id="<?php echo esc_attr($this->get_field_id('email')); ?>" name="<?php echo esc_attr($this->get_field_name('email')); ?>" type="text" value="<?php echo wp_kses_post($instance['email']); ?>" />
            </label>
        </p>

        <p>
            <label for="<?php echo esc_attr($this->get_field_id('phone_label')); ?>">
                <?php esc_html_e('Phone Label:', 'cyarb-toolkit'); ?>
                <input class="widget" id="<?php echo esc_attr($this->get_field_id('phone_label')); ?>" name="<?php echo esc_attr($this->get_field_name('phone_label')); ?>" type="text" value="<?php echo wp_kses_post($instance['phone_label']); ?>" />
            </label>
        </p>

        <p>
            <label for="<?php echo esc_attr($this->get_field_id('phone_url')); ?>">
                <?php esc_html_e('Phone URL:', 'cyarb-toolkit'); ?>
                <input class="widget" id="<?php echo esc_attr($this->get_field_id('phone_url')); ?>" name="<?php echo esc_attr($this->get_field_name('phone_url')); ?>" type="text" value="<?php echo wp_kses_post($instance['phone_url']); ?>" />
            </label>
        </p>

        <p>
            <label for="<?php echo esc_attr($this->get_field_id('phone')); ?>">
                <?php esc_html_e('Phone:', 'cyarb-toolkit'); ?>
                <input class="widget" id="<?php echo esc_attr($this->get_field_id('phone')); ?>" name="<?php echo esc_attr($this->get_field_name('phone')); ?>" type="text" value="<?php echo wp_kses_post($instance['phone']); ?>" />
            </label>
        </p>

        <p>
            <label for="<?php echo esc_attr($this->get_field_id('fax_label')); ?>">
                <?php esc_html_e('Fax Label:', 'cyarb-toolkit'); ?>
                <input class="widget" id="<?php echo esc_attr($this->get_field_id('fax_label')); ?>" name="<?php echo esc_attr($this->get_field_name('fax_label')); ?>" type="text" value="<?php echo wp_kses_post($instance['fax_label']); ?>" />
            </label>
        </p>

        <p>
            <label for="<?php echo esc_attr($this->get_field_id('fax_url')); ?>">
                <?php esc_html_e('Fax URL:', 'cyarb-toolkit'); ?>
                <input class="widget" id="<?php echo esc_attr($this->get_field_id('fax_url')); ?>" name="<?php echo esc_attr($this->get_field_name('fax_url')); ?>" type="text" value="<?php echo wp_kses_post($instance['fax_url']); ?>" />
            </label>
        </p>

        <p>
            <label for="<?php echo esc_attr($this->get_field_id('fax')); ?>">
                <?php esc_html_e('Fax:', 'cyarb-toolkit'); ?>
                <input class="widget" id="<?php echo esc_attr($this->get_field_id('fax')); ?>" name="<?php echo esc_attr($this->get_field_name('fax')); ?>" type="text" value="<?php echo wp_kses_post($instance['fax']); ?>" />
            </label>
        </p>

        <?php
    }

}

function cyarb_register_contact_info() {
    register_widget('Cyarb_contact_info');
}

add_action('widgets_init', 'cyarb_register_contact_info');